dot-wa_send_command: Send one generic shiny.webawesome browser command

.wa_send_commandR Documentation

Send one generic shiny.webawesome browser command

Description

Sends a one-way command from the Shiny server to a browser element targeted by DOM id. This is an internal transport helper used by package-level command helpers such as wa_set_property() and wa_call_method().

Usage

.wa_send_command(
  id,
  command,
  payload = list(),
  session = shiny::getDefaultReactiveDomain()
)

Arguments

id

DOM id of the target browser element.

command

Scalar command name.

payload

Optional command payload list.

session

Shiny session object. Defaults to the current reactive domain.

Value

Invisibly returns NULL.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.