View source: R/wa_animated_image.R
| wa_animated_image | R Documentation |
wa-animated-image componentGenerated wrapper for the Web Awesome wa-animated-image component.
Generated from Web Awesome metadata.
wa_animated_image(
...,
id = NULL,
class = NULL,
style = NULL,
alt = NULL,
dir = NULL,
lang = NULL,
play = NULL,
src = NULL,
pause_icon = NULL,
play_icon = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
alt |
String. A description of the image used by assistive devices. |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
play |
Boolean. Default: |
src |
String. The path to the image to load. |
pause_icon |
Optional pause icon to use instead of the default.
Works best with |
play_icon |
Optional play icon to use instead of the default.
Works best with |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.