wa_avatar: Create a 'wa-avatar' component

View source: R/wa_avatar.R

wa_avatarR Documentation

Create a wa-avatar component

Description

Generated wrapper for the Web Awesome wa-avatar component. Generated from Web Awesome metadata.

Usage

wa_avatar(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  label = NULL,
  dir = NULL,
  image = NULL,
  initials = NULL,
  lang = NULL,
  loading = NULL,
  shape = NULL,
  icon = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

label

String. Default: "". A label to use to describe the avatar to assistive devices.

dir

String. Optional Web Awesome attribute.

image

String. Default: "". The image source to use for the avatar.

initials

String. Default: "". Initials to use as a fallback when no image is available (1-2 characters max recommended).

lang

String. Optional Web Awesome attribute.

loading

Enumerated string. Allowed values: eager, lazy. Default: eager. Indicates how the browser should load the image.

shape

Enumerated string. Allowed values: circle, rounded, square. Default: circle. The shape of the avatar.

icon

The default icon to use when no image or initials are present. Works best with ⁠<wa-icon>⁠.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.