wa_breadcrumb: Create a 'wa-breadcrumb' component

View source: R/wa_breadcrumb.R

wa_breadcrumbR Documentation

Create a wa-breadcrumb component

Description

Generated wrapper for the Web Awesome wa-breadcrumb component. Generated from Web Awesome metadata.

Usage

wa_breadcrumb(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  label = NULL,
  dir = NULL,
  lang = NULL,
  separator = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

label

String. Default: "". The label to use for the breadcrumb control. This will not be shown on the screen, but it will be announced by screen readers and other assistive devices to provide more context for users.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

separator

The separator to use between breadcrumb items. Works best with ⁠<wa-icon>⁠.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.