View source: R/wa_breadcrumb_item.R
| wa_breadcrumb_item | R Documentation |
wa-breadcrumb-item componentGenerated wrapper for the Web Awesome wa-breadcrumb-item component.
Generated from Web Awesome metadata.
wa_breadcrumb_item(
...,
id = NULL,
class = NULL,
style = NULL,
dir = NULL,
href = NULL,
lang = NULL,
rel = NULL,
target = NULL,
end = NULL,
separator = NULL,
start = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
dir |
String. Optional Web Awesome attribute. |
href |
String. Optional URL to direct the user to when the breadcrumb item is activated. When set, a link will be rendered internally. When unset, a button will be rendered instead. |
lang |
String. Optional Web Awesome attribute. |
rel |
String. Default: |
target |
Enumerated string. Allowed values: |
end |
An element, such as |
separator |
The separator to use for the breadcrumb item. This
will only change the separator for this item. If you want to change it
for all items in the group, set the separator on |
start |
An element, such as |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.