wa_card: Create a 'wa-card' component

View source: R/wa_card.R

wa_cardR Documentation

Create a wa-card component

Description

Generated wrapper for the Web Awesome wa-card component. Generated from Web Awesome metadata.

Usage

wa_card(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  appearance = NULL,
  dir = NULL,
  lang = NULL,
  orientation = NULL,
  with_footer = NULL,
  with_header = NULL,
  with_media = NULL,
  actions = NULL,
  footer = NULL,
  footer_actions = NULL,
  header = NULL,
  header_actions = NULL,
  media = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

appearance

Enumerated string. Allowed values: accent, filled, filled-outlined, outlined, plain. Default: outlined. The card's visual appearance.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

orientation

Enumerated string. Allowed values: horizontal, vertical. Default: vertical. Renders the card's orientation *

with_footer

Boolean. Default: FALSE. Only required for SSR. Set to TRUE if you're slotting in a footer element so the server-rendered markup includes the footer before the component hydrates on the client.

with_header

Boolean. Default: FALSE. Only required for SSR. Set to TRUE if you're slotting in a header element so the server-rendered markup includes the header before the component hydrates on the client.

with_media

Boolean. Default: FALSE. Only required for SSR. Set to TRUE if you're slotting in a media element so the server-rendered markup includes the media before the component hydrates on the client.

actions

An optional actions section to render at the end for the horizontal card.

footer

An optional footer for the card.

footer_actions

An optional actions section to render in the footer of the vertical card.

header

An optional header for the card.

header_actions

An optional actions section to render in the header of the vertical card.

media

An optional media section to render at the start of the card.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.