| wa_carousel | R Documentation |
wa-carousel componentGenerated wrapper for the Web Awesome wa-carousel component. When
used as a Shiny input, input$<input_id> reflects the component's
current semantic activeSlide state. The Shiny value is returned as a
numeric value. This index is 0-based.
Generated from Web Awesome metadata.
wa_carousel(
input_id,
...,
class = NULL,
style = NULL,
autoplay = NULL,
autoplay_interval = NULL,
current_slide = NULL,
dir = NULL,
lang = NULL,
loop = NULL,
mouse_dragging = NULL,
navigation = NULL,
orientation = NULL,
pagination = NULL,
slides = NULL,
slides_per_move = NULL,
slides_per_page = NULL,
next_icon = NULL,
previous_icon = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
autoplay |
Boolean. Default: |
autoplay_interval |
Number. Default: |
current_slide |
Number. Default: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
loop |
Boolean. Default: |
mouse_dragging |
Boolean. Default: |
navigation |
Boolean. Default: |
orientation |
Enumerated string. Allowed values: |
pagination |
Boolean. Default: |
slides |
Number. Default: |
slides_per_move |
Number. Default: |
slides_per_page |
Number. Default: |
next_icon |
Optional next icon to use instead of the default.
Works best with |
previous_icon |
Optional previous icon to use instead of the
default. Works best with |
An HTML tag for the component.
input$<input_id> reflects the component's current semantic
activeSlide state. The Shiny value is returned as a numeric value.
This index is 0-based.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.