wa_checkbox: Create a 'wa-checkbox' component

View source: R/wa_checkbox.R

wa_checkboxR Documentation

Create a wa-checkbox component

Description

Generated wrapper for the Web Awesome wa-checkbox component. When used as a Shiny input, ⁠input$<input_id>⁠ reflects the component's current value value. The Shiny value is returned as a logical value. Generated from Web Awesome metadata.

Usage

wa_checkbox(
  input_id,
  ...,
  class = NULL,
  style = NULL,
  value = NULL,
  checked = NULL,
  disabled = NULL,
  hint = NULL,
  name = NULL,
  custom_error = NULL,
  dir = NULL,
  indeterminate = NULL,
  lang = NULL,
  required = NULL,
  size = NULL,
  title = NULL,
  hint_slot = NULL
)

Arguments

input_id

Shiny input id for the component. This is also used as the rendered DOM id attribute.

...

Child content for the component's default slot.

class

Optional CSS class string.

style

Optional inline CSS style string.

value

String. The value of the checkbox, submitted as a name/value pair with form data.

checked

Boolean. Default: FALSE. The default value of the form control. Primarily used for resetting the form control. This wrapper argument sets the HTML checked attribute, which maps to the component's defaultChecked field/property rather than its live checked property.

disabled

Boolean. Default: FALSE. Disables the checkbox.

hint

String. Default: "". The checkbox's hint. If you need to display HTML, use the hint slot instead.

name

String. Default: null. The name of the checkbox, submitted as a name/value pair with form data.

custom_error

String. Default: null. Optional Web Awesome attribute.

dir

String. Optional Web Awesome attribute.

indeterminate

Boolean. Default: FALSE. Draws the checkbox in an indeterminate state. This is usually applied to checkboxes that represents a "select all/none" behavior when associated checkboxes have a mix of checked and unchecked states.

lang

String. Optional Web Awesome attribute.

required

Boolean. Default: FALSE. Makes the checkbox a required field.

size

Enumerated string. Allowed values: large, medium, small. Default: medium. The checkbox's size.

title

String. Default: "". Optional Web Awesome attribute.

hint_slot

Text that describes how to use the checkbox. Alternatively, you can use the hint attribute.

Value

An HTML tag for the component.

Shiny Bindings

⁠input$<input_id>⁠ reflects the component's current value value. The Shiny value is returned as a logical value.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.