wa_dialog: Create a 'wa-dialog' component

View source: R/wa_dialog.R

wa_dialogR Documentation

Create a wa-dialog component

Description

Generated wrapper for the Web Awesome wa-dialog component. When used as a Shiny input, ⁠input$<input_id>⁠ reflects the component's current semantic open state. The Shiny value is returned as a logical value. Generated from Web Awesome metadata.

Usage

wa_dialog(
  input_id,
  ...,
  class = NULL,
  style = NULL,
  label = NULL,
  dir = NULL,
  lang = NULL,
  light_dismiss = NULL,
  open = NULL,
  with_footer = NULL,
  without_header = NULL,
  footer = NULL,
  header_actions = NULL,
  label_slot = NULL
)

Arguments

input_id

Shiny input id for the component. This is also used as the rendered DOM id attribute.

...

Child content for the component's default slot.

class

Optional CSS class string.

style

Optional inline CSS style string.

label

String. Default: "". The dialog's label as displayed in the header. You should always include a relevant label, as it is required for proper accessibility. If you need to display HTML, use the label slot instead.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

light_dismiss

Boolean. Default: FALSE. When enabled, the dialog will be closed when the user clicks outside of it.

open

Boolean. Default: FALSE. Indicates whether or not the dialog is open. Toggle this attribute to show and hide the dialog.

with_footer

Boolean. Default: FALSE. Only required for SSR. Set to TRUE if you're slotting in a footer element so the server-rendered markup includes the footer before the component hydrates on the client.

without_header

Boolean. Default: FALSE. Disables the header. This will also remove the default close button.

footer

The dialog's footer, usually one or more buttons representing various options.

header_actions

Optional actions to add to the header. Works best with ⁠<wa-button>⁠.

label_slot

The dialog's label. Alternatively, you can use the label attribute.

Value

An HTML tag for the component.

Shiny Bindings

⁠input$<input_id>⁠ reflects the component's current semantic open state. The Shiny value is returned as a logical value.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.