| wa_dropdown | R Documentation |
wa-dropdown componentGenerated wrapper for the Web Awesome wa-dropdown component. When
used as a Shiny input, action semantics are exposed through
input$<input_id> and the latest selected dropdown item value is
exposed through input$<input_id>_value. The action input increments
on every selection, including repeated selection of the same item. The
companion value input reflects the selected item's value, returns
NULL when the selected item has no value, and preserves an explicit
empty string "" when that is the selected item's value. Each
committed action publishes a numeric action value.
Generated from Web Awesome metadata.
wa_dropdown(
input_id,
...,
class = NULL,
style = NULL,
dir = NULL,
distance = NULL,
lang = NULL,
open = NULL,
placement = NULL,
size = NULL,
skidding = NULL,
trigger = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
dir |
String. Optional Web Awesome attribute. |
distance |
Number. Default: |
lang |
String. Optional Web Awesome attribute. |
open |
Boolean. Default: |
placement |
Enumerated string. Allowed values: |
size |
Enumerated string. Allowed values: |
skidding |
Number. Default: |
trigger |
The element that triggers the dropdown, such as a
|
An HTML tag for the component.
input$<input_id> uses action semantics and invalidates on each
committed action, including repeated selection of the same item. The
Shiny action value is returned as a numeric action value.
input$<input_id>_value reflects the latest selected item's value
value, returns NULL when the selected item has no value , and
preserves an explicit empty string "" when that is the selected
item's value. The payload value is returned as a character string or
NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.