View source: R/wa_dropdown_item.R
| wa_dropdown_item | R Documentation |
wa-dropdown-item componentGenerated wrapper for the Web Awesome wa-dropdown-item component.
Generated from Web Awesome metadata.
wa_dropdown_item(
...,
id = NULL,
class = NULL,
style = NULL,
value = NULL,
checked = NULL,
disabled = NULL,
dir = NULL,
lang = NULL,
submenu_open = NULL,
type = NULL,
variant = NULL,
details = NULL,
icon = NULL,
submenu = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
String. An optional value for the menu item. This is
useful for determining which item was selected when listening to the
dropdown's |
checked |
Boolean. Default: |
disabled |
Boolean. Default: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
submenu_open |
Boolean. Default: |
type |
Enumerated string. Allowed values: |
variant |
Enumerated string. Allowed values: |
details |
Additional content or details to display after the label. |
icon |
An optional icon to display before the label. |
submenu |
Submenu items, typically |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.