wa_icon: Create a 'wa-icon' component

View source: R/wa_icon.R

wa_iconR Documentation

Create a wa-icon component

Description

Generated wrapper for the Web Awesome wa-icon component. Generated from Web Awesome metadata.

Usage

wa_icon(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  label = NULL,
  name = NULL,
  animation = NULL,
  auto_width = NULL,
  dir = NULL,
  family = NULL,
  flip = NULL,
  lang = NULL,
  library = NULL,
  rotate = NULL,
  src = NULL,
  swap_opacity = NULL,
  variant = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

label

String. Default: "". An alternate description to use for assistive devices. If omitted, the icon will be considered presentational and ignored by assistive devices.

name

String. The name of the icon to draw. Available names depend on the icon library being used.

animation

Enumerated string. Allowed values: beat, beat-fade, bounce, fade, flip, shake, spin, spin-pulse, spin-reverse. Sets the animation for the icon

auto_width

Boolean. Default: FALSE. Sets the width of the icon to match the cropped SVG viewBox. This operates like the Font fa-width-auto class.

dir

String. Optional Web Awesome attribute.

family

String. The family of icons to choose from. For Font Awesome Free, valid options include classic and brands. For Font Awesome Pro subscribers, valid options include, classic, sharp, duotone, sharp-duotone, and brands. A valid kit code must be present to show pro icons via CDN. You can set ⁠<html data-fa-kit-code="...">⁠ to provide one.

flip

Enumerated string. Allowed values: both, x, y. Sets the flip direction of the icon along the 'x' (horizontal), 'y' (vertical), or 'both' axes.

lang

String. Optional Web Awesome attribute.

library

String. Default: default. The name of a registered custom icon library.

rotate

Number. Default: 0. Sets the rotation degree of the icon

src

String. An external URL of an SVG file. Be sure you trust the content you are including, as it will be executed as code and can result in XSS attacks.

swap_opacity

Boolean. Default: FALSE. Swaps the opacity of duotone icons.

variant

String. The name of the icon's variant. For Font Awesome, valid options include thin, light, regular, and solid for the classic and sharp families. Some variants require a Font Awesome Pro subscription. Custom icon libraries may or may not use this property.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.