| wa_include | R Documentation |
wa-include componentGenerated wrapper for the Web Awesome wa-include component.
Generated from Web Awesome metadata.
wa_include(
...,
id = NULL,
class = NULL,
style = NULL,
allow_scripts = NULL,
dir = NULL,
lang = NULL,
mode = NULL,
src = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
allow_scripts |
Boolean. Default: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
mode |
Enumerated string. Allowed values: |
src |
String. The location of the HTML file to include. Be sure you trust the content you are including as it will be executed as code and can result in XSS attacks. |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.