| wa_input | R Documentation |
wa-input componentGenerated wrapper for the Web Awesome wa-input component. When used
as a Shiny input, input$<input_id> reflects the component's current
value value.
Generated from Web Awesome metadata.
Generated update helper for the Web Awesome wa-input component.
wa_input(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
label = NULL,
hint = NULL,
name = NULL,
appearance = NULL,
autocapitalize = NULL,
autocomplete = NULL,
autocorrect = NULL,
autofocus = NULL,
custom_error = NULL,
dir = NULL,
enterkeyhint = NULL,
inputmode = NULL,
lang = NULL,
max = NULL,
maxlength = NULL,
min = NULL,
minlength = NULL,
password_toggle = NULL,
password_visible = NULL,
pattern = NULL,
pill = NULL,
placeholder = NULL,
readonly = NULL,
required = NULL,
size = NULL,
spellcheck = NULL,
step = NULL,
title = NULL,
type = NULL,
with_clear = NULL,
with_hint = NULL,
with_label = NULL,
without_spin_buttons = NULL,
clear_icon = NULL,
end = NULL,
hide_password_icon = NULL,
hint_slot = NULL,
label_slot = NULL,
show_password_icon = NULL,
start = NULL
)
update_wa_input(
session,
input_id,
value = NULL,
label = NULL,
hint = NULL,
disabled = NULL
)
input_id |
Input id of the component to update. |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
Optional value to send to the component. |
disabled |
Optional logical disabled state to send to the component. |
label |
Optional label text to send to the component. |
hint |
Optional hint text to send to the component. |
name |
String. Default: |
appearance |
Enumerated string. Allowed values: |
autocapitalize |
Enumerated string. Allowed values: |
autocomplete |
String. Specifies what permission the browser has to provide assistance in filling out form field values. Refer to this page on MDN for available values. |
autocorrect |
Boolean. Default: |
autofocus |
Boolean. Default: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
enterkeyhint |
Enumerated string. Allowed values: |
inputmode |
Enumerated string. Allowed values: |
lang |
String. Optional Web Awesome attribute. |
max |
The input's maximum value. Only applies to date and number input types. |
maxlength |
Number. The maximum length of input that will be considered valid. |
min |
The input's minimum value. Only applies to date and number input types. |
minlength |
Number. The minimum length of input that will be considered valid. |
password_toggle |
Boolean. Default: |
password_visible |
Boolean. Default: |
pattern |
String. A regular expression pattern to validate input against. |
pill |
Boolean. Default: |
placeholder |
String. Default: |
readonly |
Boolean. Default: |
required |
Boolean. Default: |
size |
Enumerated string. Allowed values: |
spellcheck |
Boolean. Default: |
step |
Specifies the granularity that the value must adhere to, or
the special value |
title |
String. Default: |
type |
Enumerated string. Allowed values: |
with_clear |
Boolean. Default: |
with_hint |
Boolean. Default: |
with_label |
Boolean. Default: |
without_spin_buttons |
Boolean. Default: |
clear_icon |
An icon to use in lieu of the default clear icon. |
end |
An element, such as |
hide_password_icon |
An icon to use in lieu of the default hide password icon. |
hint_slot |
Text that describes how to use the input.
Alternatively, you can use the |
label_slot |
The input's label. Alternatively, you can use the
|
show_password_icon |
An icon to use in lieu of the default show password icon. |
start |
An element, such as |
session |
Shiny session object. |
An HTML tag for the component.
Invisibly returns NULL.
input$<input_id> reflects the component's current value value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.