wa_mutation_observer: Create a 'wa-mutation-observer' component

View source: R/wa_mutation_observer.R

wa_mutation_observerR Documentation

Create a wa-mutation-observer component

Description

Generated wrapper for the Web Awesome wa-mutation-observer component. Generated from Web Awesome metadata.

Usage

wa_mutation_observer(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  disabled = NULL,
  attr = NULL,
  attr_old_value = NULL,
  char_data = NULL,
  char_data_old_value = NULL,
  child_list = NULL,
  dir = NULL,
  lang = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

disabled

Boolean. Default: FALSE. Disables the observer.

attr

String. Watches for changes to attributes. To watch only specific attributes, separate them by a space, e.g. attr="class id title". To watch all attributes, use *.

attr_old_value

Boolean. Default: FALSE. Indicates whether or not the attribute's previous value should be recorded when monitoring changes.

char_data

Boolean. Default: FALSE. Watches for changes to the character data contained within the node.

char_data_old_value

Boolean. Default: FALSE. Indicates whether or not the previous value of the node's text should be recorded.

child_list

Boolean. Default: FALSE. Watches for the addition or removal of new child nodes.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.