View source: R/wa_number_input.R
| wa_number_input | R Documentation |
wa-number-input componentGenerated wrapper for the Web Awesome wa-number-input component. When
used as a Shiny input, input$<input_id> reflects the component's
current value value.
Generated from Web Awesome metadata.
Generated update helper for the Web Awesome wa-number-input component.
wa_number_input(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
label = NULL,
hint = NULL,
name = NULL,
appearance = NULL,
autocomplete = NULL,
autofocus = NULL,
custom_error = NULL,
dir = NULL,
enterkeyhint = NULL,
inputmode = NULL,
lang = NULL,
max = NULL,
min = NULL,
pill = NULL,
placeholder = NULL,
readonly = NULL,
required = NULL,
size = NULL,
step = NULL,
title = NULL,
with_hint = NULL,
with_label = NULL,
without_steppers = NULL,
decrement_icon = NULL,
end = NULL,
hint_slot = NULL,
increment_icon = NULL,
label_slot = NULL,
start = NULL
)
update_wa_number_input(
session,
input_id,
value = NULL,
label = NULL,
hint = NULL,
disabled = NULL
)
input_id |
Input id of the component to update. |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
Optional value to send to the component. |
disabled |
Optional logical disabled state to send to the component. |
label |
Optional label text to send to the component. |
hint |
Optional hint text to send to the component. |
name |
String. Default: |
appearance |
Enumerated string. Allowed values: |
autocomplete |
String. Specifies what permission the browser has to provide assistance in filling out form field values. Refer to this page on MDN for available values. |
autofocus |
Boolean. Default: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
enterkeyhint |
Enumerated string. Allowed values: |
inputmode |
Enumerated string. Allowed values: |
lang |
String. Optional Web Awesome attribute. |
max |
Number. The input's maximum value. |
min |
Number. The input's minimum value. |
pill |
Boolean. Default: |
placeholder |
String. Default: |
readonly |
Boolean. Default: |
required |
Boolean. Default: |
size |
Enumerated string. Allowed values: |
step |
Default: |
title |
String. Default: |
with_hint |
Boolean. Default: |
with_label |
Boolean. Default: |
without_steppers |
Boolean. Default: |
decrement_icon |
An icon to use in lieu of the default decrement icon. |
end |
An element, such as |
hint_slot |
Text that describes how to use the input.
Alternatively, you can use the |
increment_icon |
An icon to use in lieu of the default increment icon. |
label_slot |
The input's label. Alternatively, you can use the
|
start |
An element, such as |
session |
Shiny session object. |
An HTML tag for the component.
Invisibly returns NULL.
input$<input_id> reflects the component's current value value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.