| wa_page | R Documentation |
wa-page componentGenerated wrapper for the Web Awesome wa-page component.
Generated from Web Awesome metadata.
wa_page(
...,
id = NULL,
class = NULL,
style = NULL,
dir = NULL,
disable_navigation_toggle = NULL,
lang = NULL,
mobile_breakpoint = NULL,
nav_open = NULL,
navigation_placement = NULL,
view = NULL,
aside = NULL,
banner = NULL,
footer = NULL,
header = NULL,
main_footer = NULL,
main_header = NULL,
menu = NULL,
navigation = NULL,
navigation_footer = NULL,
navigation_header = NULL,
navigation_toggle = NULL,
navigation_toggle_icon = NULL,
skip_to_content = NULL,
subheader = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
dir |
String. Optional Web Awesome attribute. |
disable_navigation_toggle |
Boolean. Default: |
lang |
String. Optional Web Awesome attribute. |
mobile_breakpoint |
String. Default: |
nav_open |
Boolean. Default: |
navigation_placement |
Enumerated string. Allowed values: |
view |
Enumerated string. Allowed values: |
aside |
Content to be shown on the right side of the page. Typically contains a table of contents, ads, etc. This section "sticks" to the top as the page scrolls. |
banner |
The banner that gets display above the header. The banner will not be shown if no content is provided. |
footer |
The content to display in the footer. This is always displayed underneath the viewport so will always make the page "scrollable". |
header |
The header to display at the top of the page. If a banner is present, the header will appear below the banner. The header will not be shown if there is no content. |
main_footer |
Footer to display inline below the main content. |
main_header |
Header to display inline above the main content. |
menu |
The left side of the page. If you slot an element in here,
you will override the default |
navigation |
The main content to display in the navigation area.
This is displayed on the left side of the page, if |
navigation_footer |
The footer for a navigation area. On mobile
this will be the footer for |
navigation_header |
The header for a navigation area. On mobile
this will be the header for |
navigation_toggle |
Use this slot to slot in your own button +
icon for toggling the navigation drawer. By default it is a
|
navigation_toggle_icon |
Use this to slot in your own icon for
toggling the navigation drawer. By default it is 3 bars |
skip_to_content |
The "skip to content" slot. You can override
this If you would like to override the |
subheader |
A subheader to display below the |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.