wa_popover: Create a 'wa-popover' component

View source: R/wa_popover.R

wa_popoverR Documentation

Create a wa-popover component

Description

Generated wrapper for the Web Awesome wa-popover component. Generated from Web Awesome metadata.

Usage

wa_popover(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  dir = NULL,
  distance = NULL,
  `for` = NULL,
  lang = NULL,
  open = NULL,
  placement = NULL,
  skidding = NULL,
  without_arrow = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

dir

String. Optional Web Awesome attribute.

distance

Number. Default: 8. The distance in pixels from which to offset the popover away from its target.

for

String. Default: null. The ID of the popover's anchor element. This must be an interactive/focusable element such as a button.

lang

String. Optional Web Awesome attribute.

open

Boolean. Default: FALSE. Shows or hides the popover.

placement

Enumerated string. Allowed values: bottom, bottom-end, bottom-start, left, left-end, left-start, right, right-end, right-start, top, top-end, top-start. Default: top. The preferred placement of the popover. Note that the actual placement may vary as needed to keep the popover inside of the viewport.

skidding

Number. Default: 0. The distance in pixels from which to offset the popover along its target.

without_arrow

Boolean. Default: FALSE. Removes the arrow from the popover.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.