| wa_popup | R Documentation |
wa-popup componentGenerated wrapper for the Web Awesome wa-popup component.
Generated from Web Awesome metadata.
wa_popup(
...,
id = NULL,
class = NULL,
style = NULL,
active = NULL,
anchor = NULL,
arrow = NULL,
arrow_padding = NULL,
arrow_placement = NULL,
auto_size = NULL,
auto_size_padding = NULL,
auto_size_boundary = NULL,
boundary = NULL,
dir = NULL,
distance = NULL,
flip = NULL,
flip_fallback_placements = NULL,
flip_fallback_strategy = NULL,
flip_padding = NULL,
flip_boundary = NULL,
hover_bridge = NULL,
lang = NULL,
placement = NULL,
shift = NULL,
shift_padding = NULL,
shift_boundary = NULL,
skidding = NULL,
sync = NULL,
anchor_slot = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
active |
Boolean. Default: |
anchor |
The element the popup will be anchored to. If the anchor
lives outside of the popup, you can provide the anchor element |
arrow |
Boolean. Default: |
arrow_padding |
Number. Default: |
arrow_placement |
Enumerated string. Allowed values: |
auto_size |
Enumerated string. Allowed values: |
auto_size_padding |
Number. Default: |
auto_size_boundary |
The auto-size boundary describes clipping element(s) that overflow will be checked relative to when resizing. By default, the boundary includes overflow ancestors that will cause the element to be clipped. If needed, you can change the boundary by passing a reference to one or more elements to this property. |
boundary |
Enumerated string. Allowed values: |
dir |
String. Optional Web Awesome attribute. |
distance |
Number. Default: |
flip |
Boolean. Default: |
flip_fallback_placements |
String. Default: |
flip_fallback_strategy |
Enumerated string. Allowed values:
|
flip_padding |
Number. Default: |
flip_boundary |
The flip boundary describes clipping element(s) that overflow will be checked relative to when flipping. By default, the boundary includes overflow ancestors that will cause the element to be clipped. If needed, you can change the boundary by passing a reference to one or more elements to this property. |
hover_bridge |
Boolean. Default: |
lang |
String. Optional Web Awesome attribute. |
placement |
Enumerated string. Allowed values: |
shift |
Boolean. Default: |
shift_padding |
Number. Default: |
shift_boundary |
The shift boundary describes clipping element(s) that overflow will be checked relative to when shifting. By default, the boundary includes overflow ancestors that will cause the element to be clipped. If needed, you can change the boundary by passing a reference to one or more elements to this property. |
skidding |
Number. Default: |
sync |
Enumerated string. Allowed values: |
anchor_slot |
The element the popup will be anchored to. If the
anchor lives outside of the popup, you can use the |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.