| wa_rating | R Documentation |
wa-rating componentGenerated wrapper for the Web Awesome wa-rating component. When used
as a Shiny input, input$<input_id> reflects the component's current
value value. The Shiny value is returned as a numeric value.
Generated from Web Awesome metadata.
wa_rating(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
label = NULL,
name = NULL,
custom_error = NULL,
default_value = NULL,
dir = NULL,
get_symbol = NULL,
lang = NULL,
max = NULL,
precision = NULL,
readonly = NULL,
required = NULL,
size = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
Number. Default: |
disabled |
Boolean. Default: |
label |
String. Default: |
name |
String. Default: |
custom_error |
String. Default: |
default_value |
Number. Default: |
dir |
String. Optional Web Awesome attribute. |
get_symbol |
A function that customizes the symbol to be rendered.
The first and only argument is the rating's current value. The function
should return a string containing trusted HTML of the symbol to render
at the specified value. Works well with |
lang |
String. Optional Web Awesome attribute. |
max |
Number. Default: |
precision |
Number. Default: |
readonly |
Boolean. Default: |
required |
Boolean. Default: |
size |
Enumerated string. Allowed values: |
An HTML tag for the component.
input$<input_id> reflects the component's current value value. The
Shiny value is returned as a numeric value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.