| wa_slider | R Documentation |
wa-slider componentGenerated wrapper for the Web Awesome wa-slider component. When used
as a Shiny input, input$<input_id> reflects the component's current
value value. The Shiny value is returned as a numeric value.
Generated from Web Awesome metadata.
Generated update helper for the Web Awesome wa-slider component.
wa_slider(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
label = NULL,
hint = NULL,
name = NULL,
autofocus = NULL,
custom_error = NULL,
dir = NULL,
indicator_offset = NULL,
lang = NULL,
max = NULL,
max_value = NULL,
min = NULL,
min_value = NULL,
orientation = NULL,
range = NULL,
readonly = NULL,
size = NULL,
step = NULL,
tooltip_distance = NULL,
tooltip_placement = NULL,
with_hint = NULL,
with_label = NULL,
with_markers = NULL,
with_tooltip = NULL,
hint_slot = NULL,
label_slot = NULL,
reference = NULL
)
update_wa_slider(
session,
input_id,
value = NULL,
label = NULL,
hint = NULL,
disabled = NULL
)
input_id |
Input id of the component to update. |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
Optional value to send to the component. |
disabled |
Optional logical disabled state to send to the component. |
label |
Optional label text to send to the component. |
hint |
Optional hint text to send to the component. |
name |
String. Default: |
autofocus |
Boolean. Default: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
indicator_offset |
Number. The starting value from which to draw the slider's fill, which is based on its current value. |
lang |
String. Optional Web Awesome attribute. |
max |
Number. Default: |
max_value |
Number. Default: |
min |
Number. Default: |
min_value |
Number. Default: |
orientation |
Enumerated string. Allowed values: |
range |
Boolean. Default: |
readonly |
Boolean. Default: |
size |
Enumerated string. Allowed values: |
step |
Number. Default: |
tooltip_distance |
Number. Default: |
tooltip_placement |
Enumerated string. Allowed values: |
with_hint |
Boolean. Default: |
with_label |
Boolean. Default: |
with_markers |
Boolean. Default: |
with_tooltip |
Boolean. Default: |
hint_slot |
Text that describes how to use the input.
Alternatively, you can use the |
label_slot |
The slider label. Alternatively, you can use the
|
reference |
One or more reference labels to show visually below the slider. |
session |
Shiny session object. |
An HTML tag for the component.
Invisibly returns NULL.
input$<input_id> reflects the component's current value value. The
Shiny value is returned as a numeric value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.