wa_split_panel: Create a 'wa-split-panel' component

View source: R/wa_split_panel.R

wa_split_panelR Documentation

Create a wa-split-panel component

Description

Generated wrapper for the Web Awesome wa-split-panel component. Generated from Web Awesome metadata.

Usage

wa_split_panel(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  disabled = NULL,
  dir = NULL,
  lang = NULL,
  orientation = NULL,
  position = NULL,
  position_in_pixels = NULL,
  primary = NULL,
  snap = NULL,
  snap_threshold = NULL,
  divider = NULL,
  end = NULL,
  start = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

disabled

Boolean. Default: FALSE. Disables resizing. Note that the position may still change as a result of resizing the host element.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

orientation

Enumerated string. Allowed values: horizontal, vertical. Default: horizontal. Sets the split panel's orientation.

position

Number. Default: 50. The current position of the divider from the primary panel's edge as a percentage 0-100. Defaults to 50% of the container's initial size.

position_in_pixels

Number. The current position of the divider from the primary panel's edge in pixels.

primary

Enumerated string. Allowed values: end, start. If no primary panel is designated, both panels will resize proportionally when the host element is resized. If a primary panel is designated, it will maintain its size and the other panel will grow or shrink as needed when the host element is resized.

snap

String. One or more space-separated values at which the divider should snap. Values can be in pixels or percentages, e.g. "100px 50%".

snap_threshold

Number. Default: 12. How close the divider must be to a snap point until snapping occurs.

divider

The divider. Useful for slotting in a custom icon that renders as a handle.

end

Content to place in the end panel.

start

Content to place in the start panel.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.