wa_tab: Create a 'wa-tab' component

View source: R/wa_tab.R

wa_tabR Documentation

Create a wa-tab component

Description

Generated wrapper for the Web Awesome wa-tab component. Generated from Web Awesome metadata.

Usage

wa_tab(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  disabled = NULL,
  dir = NULL,
  lang = NULL,
  panel = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

disabled

Boolean. Default: FALSE. Disables the tab and prevents selection.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

panel

String. Default: "". The name of the tab panel this tab is associated with. The panel must be located in the same tab group.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.