wa_tab_group: Create a 'wa-tab-group' component

View source: R/wa_tab_group.R

wa_tab_groupR Documentation

Create a wa-tab-group component

Description

Generated wrapper for the Web Awesome wa-tab-group component. When used as a Shiny input, ⁠input$<input_id>⁠ reflects the component's current semantic active state. The Shiny value is returned as a character string. Generated from Web Awesome metadata.

Usage

wa_tab_group(
  input_id,
  ...,
  class = NULL,
  style = NULL,
  activation = NULL,
  active = NULL,
  dir = NULL,
  lang = NULL,
  placement = NULL,
  without_scroll_controls = NULL,
  nav = NULL
)

Arguments

input_id

Shiny input id for the component. This is also used as the rendered DOM id attribute.

...

Child content for the component's default slot.

class

Optional CSS class string.

style

Optional inline CSS style string.

activation

Enumerated string. Allowed values: auto, manual. Default: auto. When set to auto, navigating tabs with the arrow keys will instantly show the corresponding tab panel. When set to manual, the tab will receive focus but will not show until the user presses spacebar or enter.

active

String. Default: "". Sets the active tab.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

placement

Enumerated string. Allowed values: bottom, end, start, top. Default: top. The placement of the tabs.

without_scroll_controls

Boolean. Default: FALSE. Disables the scroll arrows that appear when tabs overflow.

nav

Used for grouping tabs in the tab group. Must be ⁠<wa-tab>⁠ elements. Note that ⁠<wa-tab>⁠ will set this slot on itself automatically.

Value

An HTML tag for the component.

Shiny Bindings

⁠input$<input_id>⁠ reflects the component's current semantic active state. The Shiny value is returned as a character string.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.