wa_tag: Create a 'wa-tag' component

View source: R/wa_tag.R

wa_tagR Documentation

Create a wa-tag component

Description

Generated wrapper for the Web Awesome wa-tag component. Generated from Web Awesome metadata.

Usage

wa_tag(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  appearance = NULL,
  dir = NULL,
  lang = NULL,
  pill = NULL,
  size = NULL,
  variant = NULL,
  with_remove = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

appearance

Enumerated string. Allowed values: accent, filled, filled-outlined, outlined. Default: filled-outlined. The tag's visual appearance.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

pill

Boolean. Default: FALSE. Draws a pill-style tag with rounded edges.

size

Enumerated string. Allowed values: large, medium, small. Default: medium. The tag's size.

variant

Enumerated string. Allowed values: brand, danger, neutral, success, warning. Default: neutral. The tag's theme variant. Defaults to neutral if not within another element with a variant.

with_remove

Boolean. Default: FALSE. Makes the tag removable and shows a remove button.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.