wa_textarea: Create a 'wa-textarea' component

View source: R/wa_textarea.R

wa_textareaR Documentation

Create a wa-textarea component

Description

Generated wrapper for the Web Awesome wa-textarea component. When used as a Shiny input, ⁠input$<input_id>⁠ reflects the component's current value value. Generated from Web Awesome metadata.

Generated update helper for the Web Awesome wa-textarea component.

Usage

wa_textarea(
  input_id,
  ...,
  class = NULL,
  style = NULL,
  value = NULL,
  disabled = NULL,
  label = NULL,
  hint = NULL,
  name = NULL,
  appearance = NULL,
  autocapitalize = NULL,
  autocomplete = NULL,
  autocorrect = NULL,
  autofocus = NULL,
  custom_error = NULL,
  dir = NULL,
  enterkeyhint = NULL,
  inputmode = NULL,
  lang = NULL,
  maxlength = NULL,
  minlength = NULL,
  placeholder = NULL,
  readonly = NULL,
  required = NULL,
  resize = NULL,
  rows = NULL,
  size = NULL,
  spellcheck = NULL,
  title = NULL,
  with_count = NULL,
  with_hint = NULL,
  with_label = NULL,
  hint_slot = NULL,
  label_slot = NULL
)

update_wa_textarea(
  session,
  input_id,
  value = NULL,
  label = NULL,
  hint = NULL,
  disabled = NULL
)

Arguments

input_id

Input id of the component to update.

...

Child content for the component's default slot.

class

Optional CSS class string.

style

Optional inline CSS style string.

value

Optional value to send to the component.

disabled

Optional logical disabled state to send to the component.

label

Optional label text to send to the component.

hint

Optional hint text to send to the component.

name

String. Default: null. The name of the textarea, submitted as a name/value pair with form data.

appearance

Enumerated string. Allowed values: filled, filled-outlined, outlined. Default: outlined. The textarea's visual appearance.

autocapitalize

Enumerated string. Allowed values: characters, none, off, on, sentences, words. Controls whether and how text input is automatically capitalized as it is entered by the user.

autocomplete

String. Specifies what permission the browser has to provide assistance in filling out form field values. Refer to this page on MDN for available values.

autocorrect

Boolean. Default: FALSE. Indicates whether the browser's autocorrect feature is on or off. When set as an attribute, use "off" or "on". When set as a property, use TRUE or FALSE. Because the upstream implementation treats attributes and properties differently for this field, this argument accepts TRUE, FALSE, "on", "off", NULL. TRUE emits autocorrect="on" and FALSE emits autocorrect="off". NULL omits the attribute. Accepted string values: "on" is emitted unchanged; "off" is emitted unchanged.

autofocus

Boolean. Default: FALSE. Indicates that the input should receive focus on page load.

custom_error

String. Default: null. Optional Web Awesome attribute.

dir

String. Optional Web Awesome attribute.

enterkeyhint

Enumerated string. Allowed values: done, enter, go, next, previous, search, send. Used to customize the label or icon of the Enter key on virtual keyboards.

inputmode

Enumerated string. Allowed values: decimal, email, none, numeric, search, tel, text, url. Tells the browser what type of data will be entered by the user, allowing it to display the appropriate virtual keyboard on supportive devices.

lang

String. Optional Web Awesome attribute.

maxlength

Number. The maximum length of input that will be considered valid.

minlength

Number. The minimum length of input that will be considered valid.

placeholder

String. Default: "". Placeholder text to show as a hint when the input is empty.

readonly

Boolean. Default: FALSE. Makes the textarea readonly.

required

Boolean. Default: FALSE. Makes the textarea a required field.

resize

Enumerated string. Allowed values: auto, both, horizontal, none, vertical. Default: vertical. Controls how the textarea can be resized.

rows

Number. Default: 4. The number of rows to display by default.

size

Enumerated string. Allowed values: large, medium, small. Default: medium. The textarea's size.

spellcheck

Boolean. Default: TRUE. Enables spell checking on the textarea.

title

String. Default: "". Optional Web Awesome attribute.

with_count

Boolean. Default: FALSE. Shows a character count below the textarea. When maxlength is set, shows remaining characters instead.

with_hint

Boolean. Default: FALSE. Only required for SSR. Set to TRUE if you're slotting in a hint element so the server-rendered markup includes the hint before the component hydrates on the client.

with_label

Boolean. Default: FALSE. Only required for SSR. Set to TRUE if you're slotting in a label element so the server-rendered markup includes the label before the component hydrates on the client.

hint_slot

Text that describes how to use the input. Alternatively, you can use the hint attribute.

label_slot

The textarea's label. Alternatively, you can use the label attribute.

session

Shiny session object.

Value

An HTML tag for the component.

Invisibly returns NULL.

Shiny Bindings

⁠input$<input_id>⁠ reflects the component's current value value.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.