wa_tooltip: Create a 'wa-tooltip' component

View source: R/wa_tooltip.R

wa_tooltipR Documentation

Create a wa-tooltip component

Description

Generated wrapper for the Web Awesome wa-tooltip component. Generated from Web Awesome metadata.

Usage

wa_tooltip(
  ...,
  id = NULL,
  class = NULL,
  style = NULL,
  disabled = NULL,
  dir = NULL,
  distance = NULL,
  `for` = NULL,
  hide_delay = NULL,
  lang = NULL,
  open = NULL,
  placement = NULL,
  show_delay = NULL,
  skidding = NULL,
  trigger = NULL,
  without_arrow = NULL
)

Arguments

...

Child content for the component's default slot.

id

Optional DOM id attribute for HTML, CSS, and JS targeting.

class

Optional CSS class string.

style

Optional inline CSS style string.

disabled

Boolean. Default: FALSE. Disables the tooltip so it won't show when triggered.

dir

String. Optional Web Awesome attribute.

distance

Number. Default: 8. The distance in pixels from which to offset the tooltip away from its target.

for

String. Default: null. Optional Web Awesome attribute.

hide_delay

Number. Default: 0. The amount of time to wait before hiding the tooltip when the user mouses out.

lang

String. Optional Web Awesome attribute.

open

Boolean. Default: FALSE. Indicates whether or not the tooltip is open. You can use this in lieu of the show/hide methods.

placement

Enumerated string. Allowed values: bottom, bottom-end, bottom-start, left, left-end, left-start, right, right-end, right-start, top, top-end, top-start. Default: top. The preferred placement of the tooltip. Note that the actual placement may vary as needed to keep the tooltip inside of the viewport.

show_delay

Number. Default: 150. The amount of time to wait before showing the tooltip when the user mouses in.

skidding

Number. Default: 0. The distance in pixels from which to offset the tooltip along its target.

trigger

String. Default: ⁠hover focus⁠. Controls how the tooltip is activated. Possible options include click, hover, focus, and manual. Multiple options can be passed by separating them with a space. When manual is used, the tooltip must be activated programmatically.

without_arrow

Boolean. Default: FALSE. Removes the arrow from the tooltip.

Value

An HTML tag for the component.

Shiny Bindings

None.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.