wa_tree: Create a 'wa-tree' component

View source: R/wa_tree.R

wa_treeR Documentation

Create a wa-tree component

Description

Generated wrapper for the Web Awesome wa-tree component. When used as a Shiny input, ⁠input$<input_id>⁠ reflects the component's current semantic selectedItemIds state. The Shiny value is returned as a character vector. For stable Shiny selection values, selectable descendant wa-tree-item elements should have DOM id attributes. Generated from Web Awesome metadata.

Usage

wa_tree(
  input_id,
  ...,
  class = NULL,
  style = NULL,
  dir = NULL,
  lang = NULL,
  selection = NULL,
  collapse_icon = NULL,
  expand_icon = NULL
)

Arguments

input_id

Shiny input id for the component. This is also used as the rendered DOM id attribute.

...

Child content for the component's default slot.

class

Optional CSS class string.

style

Optional inline CSS style string.

dir

String. Optional Web Awesome attribute.

lang

String. Optional Web Awesome attribute.

selection

Enumerated string. Allowed values: leaf, multiple, single. Default: single. The selection behavior of the tree. Single selection allows only one node to be selected at a time. Multiple displays checkboxes and allows more than one node to be selected. Leaf allows only leaf nodes to be selected.

collapse_icon

The icon to show when the tree item is collapsed. Works best with ⁠<wa-icon>⁠.

expand_icon

The icon to show when the tree item is expanded. Works best with ⁠<wa-icon>⁠.

Value

An HTML tag for the component.

Shiny Bindings

⁠input$<input_id>⁠ reflects the component's current semantic selectedItemIds state. The Shiny value is returned as a character vector.


shiny.webawesome documentation built on April 22, 2026, 1:09 a.m.