| wa_tree_item | R Documentation |
wa-tree-item componentGenerated wrapper for the Web Awesome wa-tree-item component.
Generated from Web Awesome metadata.
wa_tree_item(
...,
id = NULL,
class = NULL,
style = NULL,
disabled = NULL,
dir = NULL,
expanded = NULL,
lang = NULL,
lazy = NULL,
selected = NULL,
collapse_icon = NULL,
expand_icon = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
disabled |
Boolean. Default: |
dir |
String. Optional Web Awesome attribute. |
expanded |
Boolean. Default: |
lang |
String. Optional Web Awesome attribute. |
lazy |
Boolean. Default: |
selected |
Boolean. Default: |
collapse_icon |
The icon to show when the tree item is collapsed. |
expand_icon |
The icon to show when the tree item is expanded. |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.