| wa_version | R Documentation |
Reports the Web Awesome version bundled with the current
shiny.webawesome installation.
wa_version()
A length-1 character vector containing the bundled Web Awesome version string.
wa_version()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.