| .wa_send_command | R Documentation |
Sends a one-way command from the Shiny server to a browser element targeted
by DOM id. This is an internal transport helper used by package-level
command helpers such as wa_set_property() and wa_call_method().
.wa_send_command(
id,
command,
payload = list(),
session = shiny::getDefaultReactiveDomain()
)
id |
DOM |
command |
Scalar command name. |
payload |
Optional command payload list. |
session |
Shiny session object. Defaults to the current reactive domain. |
Invisibly returns NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.