| wa_button | R Documentation |
wa-button componentGenerated wrapper for the Web Awesome wa-button component. When used
as a Shiny input, the component exposes action semantics through
input$<input_id>. The Shiny input invalidates on each committed
action rather than publishing a durable value payload. Each committed
action publishes a numeric action value.
Generated from Web Awesome metadata.
wa_button(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
name = NULL,
appearance = NULL,
custom_error = NULL,
dir = NULL,
download = NULL,
formaction = NULL,
formenctype = NULL,
formmethod = NULL,
formnovalidate = NULL,
formtarget = NULL,
href = NULL,
lang = NULL,
loading = NULL,
pill = NULL,
rel = NULL,
size = NULL,
target = NULL,
title = NULL,
type = NULL,
variant = NULL,
with_caret = NULL,
with_end = NULL,
with_start = NULL,
end = NULL,
start = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
String. The value of the button, submitted as a pair with
the button's name as part of the form data, but only when this button
is the submitter. This attribute is ignored when |
disabled |
Boolean. Default: |
name |
String. Default: |
appearance |
Enumerated string. Allowed values: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
download |
String. Tells the browser to download the linked file
as this filename. Only used when |
formaction |
String. Used to override the form owner's |
formenctype |
Enumerated string. Allowed values:
|
formmethod |
Enumerated string. Allowed values: |
formnovalidate |
Boolean. Default: |
formtarget |
Used to override the form owner's |
href |
String. When set, the underlying button will be rendered as
an |
lang |
String. Optional Web Awesome attribute. |
loading |
Boolean. Default: |
pill |
Boolean. Default: |
rel |
String. When using |
size |
Enumerated string. Allowed values: |
target |
Enumerated string. Allowed values: |
title |
String. Default: |
type |
Enumerated string. Allowed values: |
variant |
Enumerated string. Allowed values: |
with_caret |
Boolean. Default: |
with_end |
Boolean. Default: |
with_start |
Boolean. Default: |
end |
An element, such as |
start |
An element, such as |
An HTML tag for the component.
input$<input_id> uses action semantics and invalidates on each
committed action rather than publishing a durable value payload. The
Shiny action value is returned as a numeric action value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.