| wa_card | R Documentation |
wa-card componentGenerated wrapper for the Web Awesome wa-card component.
Generated from Web Awesome metadata.
wa_card(
...,
id = NULL,
class = NULL,
style = NULL,
appearance = NULL,
dir = NULL,
lang = NULL,
orientation = NULL,
with_footer = NULL,
with_header = NULL,
with_media = NULL,
actions = NULL,
footer = NULL,
footer_actions = NULL,
header = NULL,
header_actions = NULL,
media = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
appearance |
Enumerated string. Allowed values: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
orientation |
Enumerated string. Allowed values: |
with_footer |
Boolean. Default: |
with_header |
Boolean. Default: |
with_media |
Boolean. Default: |
actions |
An optional actions section to render at the end for the horizontal card. |
footer |
An optional footer for the card. |
footer_actions |
An optional actions section to render in the footer of the vertical card. |
header |
An optional header for the card. |
header_actions |
An optional actions section to render in the header of the vertical card. |
media |
An optional media section to render at the start of the card. |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.