| wa_checkbox | R Documentation |
wa-checkbox componentGenerated wrapper for the Web Awesome wa-checkbox component. When
used as a Shiny input, input$<input_id> reflects the component's
current value value. The Shiny value is returned as a logical value.
Generated from Web Awesome metadata.
wa_checkbox(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
checked = NULL,
disabled = NULL,
hint = NULL,
name = NULL,
custom_error = NULL,
dir = NULL,
indeterminate = NULL,
lang = NULL,
required = NULL,
size = NULL,
title = NULL,
hint_slot = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
String. The value of the checkbox, submitted as a name/value pair with form data. |
checked |
Boolean. Default: |
disabled |
Boolean. Default: |
hint |
String. Default: |
name |
String. Default: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
indeterminate |
Boolean. Default: |
lang |
String. Optional Web Awesome attribute. |
required |
Boolean. Default: |
size |
Enumerated string. Allowed values: |
title |
String. Default: |
hint_slot |
Text that describes how to use the checkbox.
Alternatively, you can use the |
An HTML tag for the component.
input$<input_id> reflects the component's current value value. The
Shiny value is returned as a logical value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.