| wa_container | R Documentation |
Creates a convenience <div> container for layouts and utility-class usage
within the shiny.webawesome package API. wa_container() is complementary
to htmltools::tags$div() and is not a wrapper for an upstream Web Awesome
component.
wa_container(..., id = NULL, class = NULL, style = NULL)
... |
UI children and additional HTML attributes for the container. |
id |
Optional DOM |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
The helper attaches the shiny.webawesome dependency so Web Awesome utility classes can be used even when no generated component wrappers appear in the same UI subtree.
A <div> tag with the shiny.webawesome dependency attached.
container <- wa_container(
class = "wa-stack",
wa_card("First card"),
wa_card("Second card")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.