View source: R/wa_copy_button.R
| wa_copy_button | R Documentation |
wa-copy-button componentGenerated wrapper for the Web Awesome wa-copy-button component.
Generated from Web Awesome metadata.
wa_copy_button(
...,
id = NULL,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
copy_label = NULL,
dir = NULL,
error_label = NULL,
feedback_duration = NULL,
from = NULL,
lang = NULL,
success_label = NULL,
tooltip_placement = NULL,
copy_icon = NULL,
error_icon = NULL,
success_icon = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
String. Default: |
disabled |
Boolean. Default: |
copy_label |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
error_label |
String. Default: |
feedback_duration |
Number. Default: |
from |
String. Default: |
lang |
String. Optional Web Awesome attribute. |
success_label |
String. Default: |
tooltip_placement |
Enumerated string. Allowed values: |
copy_icon |
The icon to show in the default copy state. Works best
with |
error_icon |
The icon to show when a copy error occurs. Works best
with |
success_icon |
The icon to show when the content is copied. Works
best with |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.