| wa_details | R Documentation |
wa-details componentGenerated wrapper for the Web Awesome wa-details component. When used
as a Shiny input, input$<input_id> reflects the component's current
semantic open state. The Shiny value is returned as a logical value.
Generated from Web Awesome metadata.
wa_details(
input_id,
...,
class = NULL,
style = NULL,
disabled = NULL,
name = NULL,
appearance = NULL,
dir = NULL,
icon_placement = NULL,
lang = NULL,
open = NULL,
summary = NULL,
collapse_icon = NULL,
expand_icon = NULL,
summary_slot = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
disabled |
Boolean. Default: |
name |
String. Groups related details elements. When one opens, others with the same name will close. |
appearance |
Enumerated string. Allowed values: |
dir |
String. Optional Web Awesome attribute. |
icon_placement |
Enumerated string. Allowed values: |
lang |
String. Optional Web Awesome attribute. |
open |
Boolean. Default: |
summary |
String. The summary to show in the header. If you need
to display HTML, use the |
collapse_icon |
Optional collapse icon to use instead of the
default. Works best with |
expand_icon |
Optional expand icon to use instead of the default.
Works best with |
summary_slot |
The details' summary. Alternatively, you can use
the |
An HTML tag for the component.
input$<input_id> reflects the component's current semantic open
state. The Shiny value is returned as a logical value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.