| wa_dialog | R Documentation |
wa-dialog componentGenerated wrapper for the Web Awesome wa-dialog component. When used
as a Shiny input, input$<input_id> reflects the component's current
semantic open state. The Shiny value is returned as a logical value.
Generated from Web Awesome metadata.
wa_dialog(
input_id,
...,
class = NULL,
style = NULL,
label = NULL,
dir = NULL,
lang = NULL,
light_dismiss = NULL,
open = NULL,
with_footer = NULL,
without_header = NULL,
footer = NULL,
header_actions = NULL,
label_slot = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
label |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
light_dismiss |
Boolean. Default: |
open |
Boolean. Default: |
with_footer |
Boolean. Default: |
without_header |
Boolean. Default: |
footer |
The dialog's footer, usually one or more buttons representing various options. |
header_actions |
Optional actions to add to the header. Works best
with |
label_slot |
The dialog's label. Alternatively, you can use the
|
An HTML tag for the component.
input$<input_id> reflects the component's current semantic open
state. The Shiny value is returned as a logical value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.