| wa_icon | R Documentation |
wa-icon componentGenerated wrapper for the Web Awesome wa-icon component.
Generated from Web Awesome metadata.
wa_icon(
...,
id = NULL,
class = NULL,
style = NULL,
label = NULL,
name = NULL,
animation = NULL,
auto_width = NULL,
dir = NULL,
family = NULL,
flip = NULL,
lang = NULL,
library = NULL,
rotate = NULL,
src = NULL,
swap_opacity = NULL,
variant = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
label |
String. Default: |
name |
String. The name of the icon to draw. Available names depend on the icon library being used. |
animation |
Enumerated string. Allowed values: |
auto_width |
Boolean. Default: |
dir |
String. Optional Web Awesome attribute. |
family |
String. The family of icons to choose from. For Font
Awesome Free, valid options include |
flip |
Enumerated string. Allowed values: |
lang |
String. Optional Web Awesome attribute. |
library |
String. Default: |
rotate |
Number. Default: |
src |
String. An external URL of an SVG file. Be sure you trust the content you are including, as it will be executed as code and can result in XSS attacks. |
swap_opacity |
Boolean. Default: |
variant |
String. The name of the icon's variant. For Font
Awesome, valid options include |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.