| wa_select | R Documentation |
wa-select componentGenerated wrapper for the Web Awesome wa-select component. When used
as a Shiny input, input$<input_id> reflects the component's current
value value. The Shiny value is returned as a character string for
single-select usage, or a character vector when multiple is TRUE.
Generated from Web Awesome metadata.
Generated update helper for the Web Awesome wa-select component.
wa_select(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
label = NULL,
hint = NULL,
name = NULL,
appearance = NULL,
custom_error = NULL,
dir = NULL,
lang = NULL,
max_options_visible = NULL,
multiple = NULL,
open = NULL,
pill = NULL,
placeholder = NULL,
placement = NULL,
required = NULL,
size = NULL,
with_clear = NULL,
with_hint = NULL,
with_label = NULL,
clear_icon = NULL,
end = NULL,
expand_icon = NULL,
hint_slot = NULL,
label_slot = NULL,
start = NULL
)
update_wa_select(
session,
input_id,
value = NULL,
label = NULL,
hint = NULL,
disabled = NULL
)
input_id |
Input id of the component to update. |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
Optional value to send to the component. |
disabled |
Optional logical disabled state to send to the component. |
label |
Optional label text to send to the component. |
hint |
Optional hint text to send to the component. |
name |
String. Default: |
appearance |
Enumerated string. Allowed values: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
max_options_visible |
Number. Default: |
multiple |
Boolean. Default: |
open |
Boolean. Default: |
pill |
Boolean. Default: |
placeholder |
String. Default: |
placement |
Enumerated string. Allowed values: |
required |
Boolean. Default: |
size |
Enumerated string. Allowed values: |
with_clear |
Boolean. Default: |
with_hint |
Boolean. Default: |
with_label |
Boolean. Default: |
clear_icon |
An icon to use in lieu of the default clear icon. |
end |
An element, such as |
expand_icon |
The icon to show when the control is expanded and collapsed. Rotates on open and close. |
hint_slot |
Text that describes how to use the input.
Alternatively, you can use the |
label_slot |
The input's label. Alternatively, you can use the
|
start |
An element, such as |
session |
Shiny session object. |
An HTML tag for the component.
Invisibly returns NULL.
input$<input_id> reflects the component's current value value. The
Shiny value is returned as a character string for single-select usage,
or a character vector when multiple is TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.