View source: R/wa_split_panel.R
| wa_split_panel | R Documentation |
wa-split-panel componentGenerated wrapper for the Web Awesome wa-split-panel component.
Generated from Web Awesome metadata.
wa_split_panel(
...,
id = NULL,
class = NULL,
style = NULL,
disabled = NULL,
dir = NULL,
lang = NULL,
orientation = NULL,
position = NULL,
position_in_pixels = NULL,
primary = NULL,
snap = NULL,
snap_threshold = NULL,
divider = NULL,
end = NULL,
start = NULL
)
... |
Child content for the component's default slot. |
id |
Optional DOM id attribute for HTML, CSS, and JS targeting. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
disabled |
Boolean. Default: |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
orientation |
Enumerated string. Allowed values: |
position |
Number. Default: |
position_in_pixels |
Number. The current position of the divider from the primary panel's edge in pixels. |
primary |
Enumerated string. Allowed values: |
snap |
String. One or more space-separated values at which the
divider should snap. Values can be in pixels or percentages, e.g.
|
snap_threshold |
Number. Default: |
divider |
The divider. Useful for slotting in a custom icon that renders as a handle. |
end |
Content to place in the end panel. |
start |
Content to place in the start panel. |
An HTML tag for the component.
None.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.