| wa_textarea | R Documentation |
wa-textarea componentGenerated wrapper for the Web Awesome wa-textarea component. When
used as a Shiny input, input$<input_id> reflects the component's
current value value.
Generated from Web Awesome metadata.
Generated update helper for the Web Awesome wa-textarea component.
wa_textarea(
input_id,
...,
class = NULL,
style = NULL,
value = NULL,
disabled = NULL,
label = NULL,
hint = NULL,
name = NULL,
appearance = NULL,
autocapitalize = NULL,
autocomplete = NULL,
autocorrect = NULL,
autofocus = NULL,
custom_error = NULL,
dir = NULL,
enterkeyhint = NULL,
inputmode = NULL,
lang = NULL,
maxlength = NULL,
minlength = NULL,
placeholder = NULL,
readonly = NULL,
required = NULL,
resize = NULL,
rows = NULL,
size = NULL,
spellcheck = NULL,
title = NULL,
with_count = NULL,
with_hint = NULL,
with_label = NULL,
hint_slot = NULL,
label_slot = NULL
)
update_wa_textarea(
session,
input_id,
value = NULL,
label = NULL,
hint = NULL,
disabled = NULL
)
input_id |
Input id of the component to update. |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
value |
Optional value to send to the component. |
disabled |
Optional logical disabled state to send to the component. |
label |
Optional label text to send to the component. |
hint |
Optional hint text to send to the component. |
name |
String. Default: |
appearance |
Enumerated string. Allowed values: |
autocapitalize |
Enumerated string. Allowed values: |
autocomplete |
String. Specifies what permission the browser has to provide assistance in filling out form field values. Refer to this page on MDN for available values. |
autocorrect |
Boolean. Default: |
autofocus |
Boolean. Default: |
custom_error |
String. Default: |
dir |
String. Optional Web Awesome attribute. |
enterkeyhint |
Enumerated string. Allowed values: |
inputmode |
Enumerated string. Allowed values: |
lang |
String. Optional Web Awesome attribute. |
maxlength |
Number. The maximum length of input that will be considered valid. |
minlength |
Number. The minimum length of input that will be considered valid. |
placeholder |
String. Default: |
readonly |
Boolean. Default: |
required |
Boolean. Default: |
resize |
Enumerated string. Allowed values: |
rows |
Number. Default: |
size |
Enumerated string. Allowed values: |
spellcheck |
Boolean. Default: |
title |
String. Default: |
with_count |
Boolean. Default: |
with_hint |
Boolean. Default: |
with_label |
Boolean. Default: |
hint_slot |
Text that describes how to use the input.
Alternatively, you can use the |
label_slot |
The textarea's label. Alternatively, you can use the
|
session |
Shiny session object. |
An HTML tag for the component.
Invisibly returns NULL.
input$<input_id> reflects the component's current value value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.