| wa_tree | R Documentation |
wa-tree componentGenerated wrapper for the Web Awesome wa-tree component. When used as
a Shiny input, input$<input_id> reflects the component's current
semantic selectedItemIds state. The Shiny value is returned as a
character vector. For stable Shiny selection values, selectable
descendant wa-tree-item elements should have DOM id attributes.
Generated from Web Awesome metadata.
wa_tree(
input_id,
...,
class = NULL,
style = NULL,
dir = NULL,
lang = NULL,
selection = NULL,
collapse_icon = NULL,
expand_icon = NULL
)
input_id |
Shiny input id for the component. This is also used as
the rendered DOM |
... |
Child content for the component's default slot. |
class |
Optional CSS class string. |
style |
Optional inline CSS style string. |
dir |
String. Optional Web Awesome attribute. |
lang |
String. Optional Web Awesome attribute. |
selection |
Enumerated string. Allowed values: |
collapse_icon |
The icon to show when the tree item is collapsed.
Works best with |
expand_icon |
The icon to show when the tree item is expanded.
Works best with |
An HTML tag for the component.
input$<input_id> reflects the component's current semantic
selectedItemIds state. The Shiny value is returned as a character
vector.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.